(function ($, Drupal) {
  let csrfToken;
  Drupal.behaviors.contentReporting = {
    attach: function (context, settings) {
      // Ottieni il token CSRF
      fetch('/session/token')
        .then(response => response.text())
        .then(token => {
          csrfToken = token;
          if (typeof drupalSettings.nodeId !== 'undefined') {
            var uniqueToken = new Date().getTime(); // Timestamp unico per evitare la cache
            // Function to get cookie by name
            function getCookie(name) {
              let value = `; ${document.cookie}`;
              let parts = value.split(`; ${name}=`);
              if (parts.length === 2) return parts.pop().split(';').shift();
            }
            let gdprConsent = false;
            // Get GDPR consent and category from cookies
            if (typeof Drupal.eu_cookie_compliance !== 'undefined') {
             gdprConsent = Drupal.eu_cookie_compliance.hasAgreed();
            }
           
            console.log('gdprConsent', gdprConsent);
            // Invia la richiesta di tracciamento
            fetch('/track-content?' + uniqueToken, {
              method: 'POST',
              headers: {
                'Content-Type': 'application/json',
                 'X-CSRF-Token': token, // Passa il token CSRF nell'header
              },
              body: JSON.stringify({
                nid: drupalSettings.nodeId, // Passa il node ID nel body
                gdpr_consent: gdprConsent,
              })
            })
              .then(response => {
                if (!response.ok) {
                  throw new Error('Network response was not ok');
                }
                return response.json();
              })
              .then(data => {
                console.log('Tracking success:', data);
              })
              .catch(error => {
                console.error('Tracking failed due to a network error:', error);
              });
          }
        })
        .catch(error => {
          console.error('Failed to fetch CSRF token:', error);
        });
    }
  };
  Drupal.behaviors.contentClickTracking = {
    attach: function (context, settings) {
      $('a, button, .track-click', context).on('click', function (event) {
        let elementId = $(this).attr('id') || $(this).text() || $(this).value || $(this).attr('aria-label');
        var nodeId = drupalSettings.nodeId;
        var uniqueToken = new Date().getTime(); // Timestamp unico per evitare la cache

        $.ajax({
          url: '/track-content/interaction?' + uniqueToken,
          type: 'POST',
          data: JSON.stringify({
            nid: nodeId,
            interaction_type: 'click',
            element: elementId ? elementId : 'button'
          }),
          contentType: 'application/json',
          headers: {
            'X-CSRF-Token': csrfToken
          },
          success: function (response) {
            console.log('Click tracciato con successo.');
          },
          error: function (error) {
            console.log('Errore nel tracciare il click:', error);
          }
        });
      });
    }
  };
  var timeSpent = 0;
  setInterval(function() {
    timeSpent += 10; // Aggiungi 10 secondi
    fetch('/track-content/interaction?' + new Date().getTime(), {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
        'X-CSRF-Token': csrfToken,
      },
      body: JSON.stringify({
        nid: drupalSettings.nodeId,
        interaction_type: 'time_spent',
        duration: timeSpent
      })
    });
  }, 10000); // Ogni 10 secondi
})(jQuery, Drupal);

