<?php 

namespace Drupal\content_reporting_charts\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Database\Connection;

class ContentReportingChartsController extends ControllerBase {

  protected $database;
  protected $chartsSettings;

  public function __construct(Connection $database) {
    $this->database = $database;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database'),
    );
  }
public function get_page_views_data() {
    $connection = $this->database;
    $query = $connection->select('content_reporting_reports', 'r')
        ->fields('r', ['title', 'views'])
        ->orderBy('title', 'ASC') // Ordinamento per titolo della pagina
        ->execute()
        ->fetchAllAssoc('title');
    
    $data = [
        'titles' => [],
        'views' => [],
    ];

    foreach ($query as $row) {
        $data['titles'][] = $row->title;
        $data['views'][] = (int) $row->views;
    }
  
    return $data;
  }

  public function dashboard() {
    $data = $this->get_page_views_data();
    /*
 // Render the element.
 $chart = [
    '#type' => 'chart',
    '#id' => 'content_reporting_graph',
    '#title' => 'Views and GDPR Consents per Page',
    '#chart_id' => 'content_reporting_graph',
    '#chart_type' => 'column',

  ];
  $chart['series'] = [
    '#type' => 'chart_data',
    '#title' => $this->t('Views'),
    '#data' => $views,
  ];
  $chart['y_axis'] = [
    '#type' => 'chart_yaxis',
    '#title' => $this->t('GDPR Consents'),
    '#labels' => $consents ,
  ];
  $chart['x_axis'] = [
    '#type' => 'chart_xaxis',
    '#labels' => $labels,
  ];
  */
    $chart = [
      '#type' => 'chart',
      '#id' => 'content_reporting_page_views_chart',
      '#title' => 'Page Views per Page',
      '#chart_id' => 'content_reporting_page_views_chart',
      '#chart_type' => 'column', // Usa un grafico a colonne per mostrare le visualizzazioni
    ];
// Imposta i dati della serie
$chart['series'] = [
    '#type' => 'chart_data',
    '#title' => $this->t('Views'),
    '#data' => array_map(
        function($title, $views) {
            return ['name' => $title, 'y' => $views];
        },
        $data['titles'],
        $data['views']
    ),
  ];
  
  // Imposta le etichette dell'asse x
  $chart['x_axis'] = [
    '#type' => 'chart_xaxis',
    '#labels' => $data['titles'],
  ];
  
  // Imposta le etichette dell'asse y
  $chart['y_axis'] = [
    '#type' => 'chart_yaxis',
    '#title' => $this->t('Number of Views'),
];
  
    return [
      '#theme' => 'content_reporting_charts_dashboard',
      '#chart' => $chart,
    ];
  }
}
