<?php

namespace Drupal\content_reporting\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

class ContentReportingFiltersForm extends FormBase {

  public function getFormId() {
    return 'content_reporting_filters_form';
  }

  public function buildForm(array $form, FormStateInterface $form_state) {
    // Access the request directly
    $request = \Drupal::request();

    $form['title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Page Title'),
      '#default_value' => $request->query->get('title'),
    ];

    $form['start_date'] = [
      '#type' => 'date',
      '#title' => $this->t('Start Date'),
      '#default_value' => $request->query->get('start_date'),
    ];

    $form['end_date'] = [
      '#type' => 'date',
      '#title' => $this->t('End Date'),
      '#default_value' => $request->query->get('end_date'),
    ];

    $form['gdpr_consent'] = [
      '#type' => 'select',
      '#title' => $this->t('GDPR Consent'),
      '#options' => [
        '' => $this->t('- Any -'),
        '0_cons' => $this->t('0% Consents'),
        '0_25' => $this->t('0% - 25% Consents'),
        '25_50' => $this->t('25% - 50% Consents'),
        '50_70' => $this->t('50% - 70% Consents'),
        '70_100' => $this->t('70% - 100% Consents'),
      ],
      '#default_value' => $request->query->get('gdpr_consent'),
    ];

    $form['actions'] = [
      '#type' => 'actions',
      'submit' => [
        '#type' => 'submit',
        '#value' => $this->t('Filter'),
        '#button_type' => 'primary',
      ],
      'reset' => [
        '#type' => 'submit',
        '#value' => $this->t('Reset'),
        '#button_type' => 'secondary',
        '#submit' => ['::resetForm'],
      ],
    ];

    return $form;
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    $query = $form_state->getValues();
    $query['title'] = $form_state->getValue('title');
    $query['start_date'] = $form_state->getValue('start_date');
    $query['end_date'] = $form_state->getValue('end_date');
    $query['gdpr_consent'] = $form_state->getValue('gdpr_consent');

    $form_state->setRedirect('content_reporting.dashboard', $query);
  }

  /**
   * Custom submit handler for the reset button.
   */
  public function resetForm(array &$form, FormStateInterface $form_state) {
    // Redirect to the form with default values (empty query parameters)
    $form_state->setRedirect('content_reporting.dashboard');
  }
}
